Struct amazon_sp_fba_small_and_light::models::small_and_light_fee_previews::SmallAndLightFeePreviews
source · [−]pub struct SmallAndLightFeePreviews {
pub data: Option<Vec<FeePreview>>,
}Fields
data: Option<Vec<FeePreview>>A list of fee estimates for the requested items. The order of the fee estimates will follow the same order as the items in the request, with duplicates removed.
Implementations
sourceimpl SmallAndLightFeePreviews
impl SmallAndLightFeePreviews
pub fn new() -> SmallAndLightFeePreviews